###################################################################################
###############    Paper: Land competition under telecoupling     #################
###############             in north-eastern Madagascar           #################
###################################################################################

### Date: 10.12.2018
### Script by O. Ravaka Andrianihaja

### Part 1: One-mode networks graphs per village and per type of flows (with fruchtman reingold layout and fixing the actors coordinates)   
### Part 2: One-mode networks graphs per village of the institutions (with fruchtman reingold layout, fixing the vertex coordinates)  
### Part 3: Setting the vertex and the edges attributes 
### Part 4: Plotting the network graphs

#==================================================================================
# GETTING PREPARED
#==================================================================================
rm(list = ls ()) 

#install SNA packages
#install.packages("statnet") # statnet package
#install.packages("ggplot2")
#install.packages("GGally") # ggnet2 package
#install.packages("texreg") # to explort results

library(statnet)
library(ggplot2)
library(GGally)
library(texreg)
library(scales)

# set working directory
setwd("C:/Users/ravaka.andriamihaja/Dropbox/LU_DM_data/data_analysis/Paper 1_Submission") # for desktop
#setwd("C:/Users/Ravaka Andriamihaja/Dropbox/LU_DM_data/data_analysis/Paper 1_Submission") # for laptop
getwd()

set.seed(12345) # Se the system seed in order to be able to replicate results.

###################################################################################
############### Part 1: One-mode networks graphs per village and per type of flows
############### (with fruchtman reingold layout and fixing the actors coordinates)                  
###################################################################################
#==================================================================================
# LOAD DATA
#==================================================================================

### Dataset from Ravaka's FM2 in Dec 2016 to April 2017
### data on: 
#           edgelist from sending to receiving actor, connections are the flows between actors, flows include information, money, goods
#           edgelist from the actors that are adhering to institutions

####### import edgelist data ##########################

## flow edgelist
# here, we import an edgelist, where the type of flow is an attribute to the tie between sendeing and receiving actor
# for the 2 villages

flowsMorafeno <- read.csv("flowsMor.csv", sep=";", header = TRUE)
class(flowsMorafeno) # data.frame

flowsMahalevona <- read.csv("flowsMah.csv", sep=";", header = TRUE)
class(flowsMorafeno) # data.frame

# delete unneccessary columns and naming the rest

flowsMorafeno <- flowsMorafeno[c(1,2,3)]
headers_flowsMorafeno <- c("from", "to", "type")
colnames(flowsMorafeno) <- headers_flowsMorafeno

flowsMahalevona <- flowsMahalevona[c(1,2,3)]
headers_flowsMahalevona <- c("from", "to", "type")
colnames(flowsMahalevona) <- headers_flowsMahalevona

###### import node attribute data ######################
# actor attributes
attr <- read.csv("data_attributes_actors_all.csv", sep=";") 

# delete unneccessary columns (but only now)
attributes <- attr
attributes <- attributes[c(1, 4, 7, 9, 10, 11, 14, 15, 17, 18, 19, 20)]
headers_attributes <- c("ID", "place","abbr. org. name", "org. name","position", "domain","level", 
                        "sector", "Morlink", "Bealink", "Mahlink", "Fizlink")
colnames(attributes) <- headers_attributes

#==================================================================================
# PREPARE RAW DATA FOR NETWORK ANALYSIS
#==================================================================================
#### The goal is to convert the edgelist into a matrix, and then into a network object. 
# Several steps are necessary: 

#==================================================================================
###################### STEP 1: create matrix
### create four different matrices for the different villages

## Morafeno matrix
actors <- unique(c(as.character(flowsMorafeno$from), as.character(flowsMorafeno$to)))
length(actors)

# create emtpy matrix with as many rows and columns as there are actors in the network
matMor <- matrix(0, nrow = length(actors), ncol = length(actors))
colnames(matMor) <- as.character(actors)
rownames(matMor) <- as.character(actors)
matMor[1:4, 1:4]

# fill empty matrix every time an actors sends a flow to another actor, 
# there will be a 1 or 2 or 3 ... in the matrix depending on how many times the flows occur
for (i in 1:nrow(flowsMorafeno)) {
  row.index.Mor <- which(actors == flowsMorafeno$from[i])
  col.index.Mor <- which(actors == flowsMorafeno$to[i])
  matMor[row.index.Mor, col.index.Mor] <- matMor[row.index.Mor, col.index.Mor] + 1
}  
matMor[1:4, 1:4] 

ggnet2(matMor) # check

class(matMor)
ggnet2(matMor)


## Mahalevona matrix
actors <- unique(c(as.character(flowsMahalevona$from), as.character(flowsMahalevona$to)))
length(actors)
# actors <- as.data.frame(actors)

# create emtpy matrix with as many rows and columns as there are actors in the network
matMah <- matrix(0, nrow = length(actors), ncol = length(actors))
colnames(matMah) <- as.character(actors)
rownames(matMah) <- as.character(actors)
matMah[1:4, 1:4]

# fill empty matrix every time an actors sends a flow to another actor, 
# there will be a 1 or 2 or 3 ... in the matrix depending on how many times the flows occur
for (i in 1:nrow(flowsMahalevona)) {
  row.index.Mah <- which(actors == flowsMahalevona$from[i])
  col.index.Mah <- which(actors == flowsMahalevona$to[i])
  matMah[row.index.Mah, col.index.Mah] <- matMah[row.index.Mah, col.index.Mah] + 1
}  
matMah[1:4, 1:4] 

ggnet2(matMah) # check

class(matMah)
ggnet2(matMah)

#==================================================================================
######### STEP 2: class as network objects
# define as network object: matrices have to be transformed into network objects so that R can work with it
class(matMor)
class(matMah)

Mornw <- network(matMor, directed = TRUE)
Mahnw <- network(matMah, directed = TRUE)

class(Mornw)
class(Mahnw)

ggnet2(Mornw) # check
ggnet2(Mahnw) # check

#==================================================================================
### create four different matrices for the different types of flows per village

##### Morafeno village

levels(flowsMorafeno$type)
actors <- unique(c(as.character(flowsMorafeno$from), as.character(flowsMorafeno$to)))
length(actors)

## goods matrix for Morafeno
matMorgoods <- matrix(0, nrow = length(actors), ncol = length(actors)) # create an empty matrix
colnames(matMorgoods)<- as.character(actors) # insert the actors as column names
rownames(matMorgoods) <- as.character(actors) # insert the actros as row names
matMorgoods[1:4, 1:4] # check

# do a loop to fill the empty matrix with 1-entries whenever an actor sends a good to another actor
for (i in 1:nrow(flowsMorafeno)) { # tell R to go through all rows in the edgelist "flows"
  if(flowsMorafeno$type[i] == "goods") { # if the column of the edgelist "flow", has the entry "goods"
    row.index.Mor.goods <- which(actors == flowsMorafeno$from[i]) # then retain the "from" actor in row.index (row.index could be named differently)
    col.index.Mor.goods <- which(actors == flowsMorafeno$to[i]) # also retain the "to" actor in a col.index
    matMorgoods[row.index.Mor.goods, col.index.Mor.goods] <- matMorgoods[row.index.Mor.goods, col.index.Mor.goods] + 1 # and insert a 1 such that it connects sender and receiver
  }
}  
matMorgoods[1:20, 1:20]

class(matMorgoods)
ggnet2(matMorgoods)

## money matrix for Morafeno

matMormoney <- matrix(0, nrow = length(actors), ncol = length(actors)) # create an empty matrix
colnames(matMormoney)<- as.character(actors) # insert the actors as column names
rownames(matMormoney) <- as.character(actors) # insert the actros as row names
matMormoney[1:4, 1:4] # check

# do a loop to fill the empty matrix with 1-entries whenever an actor sends a good to another actor
for (i in 1:nrow(flowsMorafeno)) { # tell R to go through all rows in the edgelist "flows"
  if(flowsMorafeno$type[i] == "money") { # if the column of the edgelist "flow", has the entry "money"
    row.index.Mor.money <- which(actors == flowsMorafeno$from[i]) # then retain the "from" actor in row.index (row.index could be named differently)
    col.index.Mor.money <- which(actors == flowsMorafeno$to[i]) # also retain the "to" actor in a col.index
    matMormoney[row.index.Mor.money, col.index.Mor.money] <- matMormoney[row.index.Mor.money, col.index.Mor.money] + 1 # and insert a 1 such that it connects sender and receiver
  }
}  
matMormoney[1:20, 1:20]

class(matMormoney)
ggnet2(matMormoney)


##### Mahalevona village

levels(flowsMahalevona$type)
actors <- unique(c(as.character(flowsMahalevona$from), as.character(flowsMahalevona$to)))
length(actors)

## goods matrix for Mahalevona
matMahgoods <- matrix(0, nrow = length(actors), ncol = length(actors)) # create an empty matrix
colnames(matMahgoods)<- as.character(actors) # insert the actors as column names
rownames(matMahgoods) <- as.character(actors) # insert the actros as row names
matMahgoods[1:4, 1:4] # check

# do a loop to fill the empty matrix with 1-entries whenever an actor sends a good to another actor
for (i in 1:nrow(flowsMahalevona)) { # tell R to go through all rows in the edgelist "flows"
  if(flowsMahalevona$type[i] == "goods") { # if the column of the edgelist "flow", has the entry "goods"
    row.index.Mah.goods <- which(actors == flowsMahalevona$from[i]) # then retain the "from" actor in row.index (row.index could be named differently)
    col.index.Mah.goods <- which(actors == flowsMahalevona$to[i]) # also retain the "to" actor in a col.index
    matMahgoods[row.index.Mah.goods, col.index.Mah.goods] <- matMahgoods[row.index.Mah.goods, col.index.Mah.goods] + 1 # and insert a 1 such that it connects sender and receiver
  }
}  
matMahgoods[1:20, 1:20]

class(matMahgoods)
ggnet2(matMahgoods)

## money matrix for Mahalevona
matMahmoney <- matrix(0, nrow = length(actors), ncol = length(actors)) # create an empty matrix
colnames(matMahmoney)<- as.character(actors) # insert the actors as column names
rownames(matMahmoney) <- as.character(actors) # insert the actros as row names
matMahmoney[1:4, 1:4] # check

# do a loop to fill the empty matrix with 1-entries whenever an actor sends a good to another actor
for (i in 1:nrow(flowsMahalevona)) { # tell R to go through all rows in the edgelist "flows"
  if(flowsMahalevona$type[i] == "money") { # if the column of the edgelist "flow", has the entry "money"
    row.index.Mah.money <- which(actors == flowsMahalevona$from[i]) # then retain the "from" actor in row.index (row.index could be named differently)
    col.index.Mah.money <- which(actors == flowsMahalevona$to[i]) # also retain the "to" actor in a col.index
    matMahmoney[row.index.Mah.money, col.index.Mah.money] <- matMahmoney[row.index.Mah.money, col.index.Mah.money] + 1 # and insert a 1 such that it connects sender and receiver
  }
}  
matMahmoney[1:20, 1:20]

class(matMahmoney)
ggnet2(matMahmoney)

#==================================================================================
######### STEP 2: class as network objects
# define as network object: matrices have to be transformed into network objects so that R can work with it
class(matMorgoods)
class(matMormoney)

class(matMahgoods)
class(matMahmoney)

Morgoodsnw <- network(matMorgoods, directed = TRUE)
Mormoneynw <- network(matMormoney, directed = TRUE)

Mahgoodsnw <- network(matMahgoods, directed = TRUE)
Mahmoneynw <- network(matMahmoney, directed = TRUE)

class(Morgoodsnw)
class(Mormoneynw)

class(Mahgoodsnw)
class(Mahmoneynw)

ggnet2(Morgoodsnw) # check
ggnet2(Mormoneynw) # check

ggnet2(Mahgoodsnw) # check
ggnet2(Mahmoneynw) # check

###################################################################################
############### Part 2: One-mode networks graphs per village of the institutions ## 
###############              (with fruchtman reingold layout,                    ##
###############            fixing the vertex coordinates)                        ##
###################################################################################

### import data as edge list

# actors are in the first two columns, the institutions they belong to are in the third column for the 2 villages
# matrix of the shared institutions among the actors for the 2 villages

matMorInst = read.csv("matMorInst.csv", sep=";", row.names=1)
matMorInst <- as.matrix(matMorInst)

matMahInst = read.csv("matMahInst.csv", sep=";", row.names=1)
matMahInst <- as.matrix(matMahInst)

###### import node attribute data for institutions ######################
# institution attributes
attr.inst <- read.csv("inst.attributes.csv", sep=";") 
#head(attr.inst) # check if correct
#tail(attr.inst)

###### import node attribute data for actors ######################
# actor attributes
attr.actors <- read.csv("data_attributes_actors_all.csv", sep=";") 
#head(attr.actors) # check if correct
#tail(attr.actors)

#==================================================================================
######### STEP 2: class as network objects
# define as network object: matrices have to be transformed into network objects so that R can work with it
class(matMorInst)
class(matMahInst)

MorInstnw <- network(matMorInst, directed = FALSE)
MahInstnw <- network(matMahInst, directed = FALSE)

class(MorInstnw)
class(MahInstnw)

diag(matMorInst) <- 0
diag(matMahInst) <- 0

ggnet2(MorInstnw) # check
ggnet2(MahInstnw) # check

###################################################################################
###################################################################################
###############     Part 3: Setting the vertex and the edges attributes     #######
###################################################################################
###################################################################################

### Coordinates for the overview network graphs
# import the coordonates files for the vertex coords
coord_Mor <- read.csv("xycoordsMor.csv", sep = ";", header = TRUE)
coord_Mah <- read.csv("xycoordsMah.csv", sep = ";", header = TRUE)

### Coordinates for the zoom-in network graphs
# if you want to compare ties in, e.g., money and goods network, you have to fix the coordinates of the actors 
coord_Mor1 <- read.csv("coord_Morfv.csv", sep = ",", header = TRUE)
coord_Mah1 <-  read.csv("coord_Mahfv.csv", sep = ",", header = TRUE)

# create an attribute file in which you store all the actor attributes PER VILLAGE
# Morafeno
attributes$ID <- as.character(attributes$ID)
attributes$place <- as.character(attributes$place)
attributes$"abbr. org. name" <- as.character(attributes$"abbr. org. name")
attributes$level <- as.character(attributes$level)
attributes$sector <- as.character(attributes$sector)
attributes$Morlink <- as.character(attributes$Morlink)
attributes$Mahlink <- as.character(attributes$Mahlink)

attMor <- data.frame("actorID" = rownames(matMor)) # create a data.frame, order of actor is identical to the order of actors in the flow matrix 
attMor

coord_Mor1$"actorID" <- attMor$actorID 

attMor$actorID <- as.character(attMor$actorID)
attMor$place <- attributes$"place"[match(attMor$actorID, attributes$ID)]# match the actor of the attribute file with actor of the l file (where level attributes got imported)
attMor$abbr._org._name <- attributes$"abbr. org. name"[match(attMor$actorID, attributes$ID)]
attMor$level <- attributes$"level"[match(attMor$actorID, attributes$ID)]
attMor$sector <- attributes$"sector"[match(attMor$actorID, attributes$ID)]
attMor$Morlink <- attributes$"Morlink"[match(attMor$actorID, attributes$ID)]
attMor$x <- coord_Mor$"x"[match(attMor$actorID, coord_Mor$ID)]
attMor$y <- coord_Mor$"y"[match(attMor$actorID, coord_Mor$ID)]
attMor$m<- coord_Mor1$"V1"[match(attMor$actorID, coord_Mor1$actorID)]
attMor$n <- coord_Mor1$"V2"[match(attMor$actorID, coord_Mor1$actorID)]

set.vertex.attribute(Mornw, "x", as.numeric(attMor$x))
set.vertex.attribute(Morgoodsnw, "x", as.numeric(attMor$x))
set.vertex.attribute(Mormoneynw, "x", as.numeric(attMor$x))
set.vertex.attribute(Morgoodsnw, "m", as.numeric(attMor$m))
set.vertex.attribute(Mormoneynw, "m", as.numeric(attMor$m))

set.vertex.attribute(Mornw, "y", as.numeric(attMor$y))
set.vertex.attribute(Morgoodsnw, "y", as.numeric(attMor$y))
set.vertex.attribute(Mormoneynw, "y", as.numeric(attMor$y))
set.vertex.attribute(Morgoodsnw, "n", as.numeric(attMor$n))
set.vertex.attribute(Mormoneynw, "n", as.numeric(attMor$n))


# Mahalevona

attMah <- data.frame("actorID" = rownames(matMah)) # create a data.frame, order of actor is identical to the order of actors in the flow matrix 
attMah

coord_Mah1$"actorID" <- attMah$actorID 

attMah$actorID <- as.character(attMah$actorID)
attMah$place <- attributes$"place"[match(attMah$actorID, attributes$ID)]
attMah$abbr._org._name <- attributes$"abbr. org. name"[match(attMah$actorID, attributes$ID)]
attMah$level <- attributes$"level"[match(attMah$actorID, attributes$ID)]
attMah$sector <- attributes$"sector"[match(attMah$actorID, attributes$ID)]
attMah$Mahlink <- attributes$"Mahlink"[match(attMah$actorID, attributes$ID)]
attMah$x <- coord_Mah$"x"[match(attMah$actorID, coord_Mah$ID)]
attMah$y <- coord_Mah$"y"[match(attMah$actorID, coord_Mah$ID)]
attMah$m<- coord_Mah1$"V1"[match(attMah$actorID, coord_Mah1$actorID)]
attMah$n <- coord_Mah1$"V2"[match(attMah$actorID, coord_Mah1$actorID)]

set.vertex.attribute(Mahnw, "x", as.numeric(attMah$x))
set.vertex.attribute(Mahgoodsnw, "x", as.numeric(attMah$x))
set.vertex.attribute(Mahmoneynw, "x", as.numeric(attMah$x))
set.vertex.attribute(Mahgoodsnw, "m", as.numeric(attMah$m))
set.vertex.attribute(Mahmoneynw, "m", as.numeric(attMah$m))

set.vertex.attribute(Mahnw, "y", as.numeric(attMah$y))
set.vertex.attribute(Mahgoodsnw, "y", as.numeric(attMah$y))
set.vertex.attribute(Mahmoneynw, "y", as.numeric(attMah$y))
set.vertex.attribute(Mahgoodsnw, "n", as.numeric(attMah$n))
set.vertex.attribute(Mahmoneynw, "n", as.numeric(attMah$n))

# Morafeno_Institutions
attributes$ID <- as.character(attributes$ID)
attributes$place <- as.character(attributes$place)
attributes$`abbr. org. name` <- as.character(attributes$`abbr. org. name`)
attributes$level <- as.character(attributes$level)
attributes$sector <- as.character(attributes$sector)
attributes$Morlink <- as.character(attributes$Morlink)
attributes$Mahlink <- as.character(attributes$Mahlink)

#attMorInst2$actorID <- as.character(attMorInst2$actorID)
attMorInst2 <- data.frame("actorID" = rownames(matMorInst)) # create a data.frame, order of actor is identical to the order of actors in the flow matrix 
attMorInst2
attMorInst2$place <-attributes$"place"[match(attMorInst2$actorID, attributes$ID)]
attMorInst2$level <- attributes$"level"[match(attMorInst2$actorID, attributes$ID)]
attMorInst2$sector <- attributes$"sector"[match(attMorInst2$actorID, attributes$ID)]
attMorInst2$Morlink <- attributes$"Morlink"[match(attMorInst2$actorID, attributes$ID)]
attMorInst2$w<- coord_Mor$"x"[match(attMorInst2$actorID, coord_Mor$ID)]
attMorInst2$z<- coord_Mor$"y"[match(attMorInst2$actorID, coord_Mor$ID)]

set.vertex.attribute(MorInstnw, "w", as.numeric(attMorInst2$w))
set.vertex.attribute(MorInstnw, "z", as.numeric(attMorInst2$z))

# Mahalevona_Institutions
attMahInst2 <- data.frame("actorID" = rownames(matMahInst)) # create a data.frame, order of actor is identical to the order of actors in the flow matrix 
attMahInst2
attMahInst2$lowners <- attributes$"land owners"[match(attMahInst2$actorID, attributes$ID)] # match the actor of the attribute file with actor of the l file (where level attributes got imported)
attMahInst2$place <-attributes$"place"[match(attMahInst2$actorID, attributes$ID)]
attMahInst2$level <- attributes$"level"[match(attMahInst2$actorID, attributes$ID)]
attMahInst2$sector <- attributes$"sector"[match(attMahInst2$actorID, attributes$ID)]
attMahInst2$Mahlink <- attributes$"Mahlink"[match(attMahInst2$actorID, attributes$ID)]
attMahInst2$w<- coord_Mah$"x"[match(attMahInst2$actorID, coord_Mah$ID)]
attMahInst2$z<- coord_Mah$"y"[match(attMahInst2$actorID, coord_Mah$ID)]

set.vertex.attribute(MahInstnw, "w", as.numeric(attMahInst2$w))
set.vertex.attribute(MahInstnw, "z", as.numeric(attMahInst2$z))

# set the vertex label and color

### Sector
attMor$sector <- as.character(attMor$sector)
attMah$sector <- as.character(attMah$sector)

set.vertex.attribute(MorInstnw, "sector", as.character(attMorInst2$sector))
set.vertex.attribute(Mornw, "sector", as.character(attMor$sector))
set.vertex.attribute(Morgoodsnw, "sector", as.character(attMor$sector))
set.vertex.attribute(Mormoneynw, "sector", as.character(attMor$sector))

set.vertex.attribute(MahInstnw, "sector", as.character(attMahInst2$sector))
set.vertex.attribute(Mahnw, "sector", as.character(attMah$sector))
set.vertex.attribute(Mahgoodsnw, "sector", as.character(attMah$sector))
set.vertex.attribute(Mahmoneynw, "sector", as.character(attMah$sector))

### Abbreviation of the name of the organisation
attMor$"abbr._org._name" <- as.character(attMor$"abbr._org._name")
attMah$"abbr._org._name" <- as.character(attMah$"abbr._org._name")

set.vertex.attribute(MorInstnw, "org.name", as.character(attMorInst2$actorID))
set.vertex.attribute(Mornw, "org.name", as.character(attMor$"abbr._org._name"))
set.vertex.attribute(Morgoodsnw, "org.name", as.character(attMor$"abbr._org._name"))
set.vertex.attribute(Mormoneynw, "org.name", as.character(attMor$"abbr._org._name"))

set.vertex.attribute(MahInstnw, "org.name", as.character(attMahInst2$actorID))
set.vertex.attribute(Mahnw, "org.name", as.character(attMah$"abbr._org._name"))
set.vertex.attribute(Mahgoodsnw, "org.name", as.character(attMah$"abbr._org._name"))
set.vertex.attribute(Mahmoneynw, "org.name", as.character(attMah$"abbr._org._name"))

### Level
attMor$level <- as.character(attMor$level)
attMah$level <- as.character(attMah$level)

set.vertex.attribute(MorInstnw, "level", as.character(attMorInst2$level))
set.vertex.attribute(Mornw, "level", as.character(attMor$level))
set.vertex.attribute(Morgoodsnw, "level", as.character(attMor$level))
set.vertex.attribute(Mormoneynw, "level", as.character(attMor$level))

set.vertex.attribute(MahInstnw, "level", as.character(attMahInst2$level))
set.vertex.attribute(Mahnw, "level", as.character(attMah$level))
set.vertex.attribute(Mahgoodsnw, "level", as.character(attMah$level))
set.vertex.attribute(Mahmoneynw, "level", as.character(attMah$level))

# delete the isolated vertex

delete.vertices(MorInstnw, which(degree(MorInstnw) < 1))
delete.vertices(Morgoodsnw, which(degree(Morgoodsnw) < 1))
delete.vertices(Mormoneynw, which(degree(Mormoneynw) < 1))

delete.vertices(MahInstnw, which(degree(MahInstnw) < 1))
delete.vertices(Mahgoodsnw, which(degree(Mahgoodsnw) < 1))
delete.vertices(Mahmoneynw, which(degree(Mahmoneynw) < 1))

#utils::View(flowsMah)
###################################################################################
###################################################################################
###############     Part 4: Plotting the network graphs     #######################
###################################################################################
###################################################################################

###################### Plotting the village-network graphs with labels ######################################

# Morafeno

pdf("Morgoodsnw4.pdf", width = 20, height = 10)

ggnet2(Morgoodsnw, mode = c("m","n"), label = "org.name", color = "sector", palette = c("Public sector" = "#2c7bb6", 
                                                                                        "Private sector" = "#d7191c", 
                                                                                        "Voluntary sector" = "#fdae61"), 
       label.size = 8, edge.color = "#000000",
       shape = "level", shape.palette = c("startMor" = 19, "startMah" = 19, "startBea" = 19, "startFiz" = 19, 
                                          "village" = 19, 
                                          "district" = 15, 
                                          "regional" = 8, 
                                          "national" = 17, 
                                          "international" = 18),
       size = 10, legend.size = 16, legend.position = "right")
dev.off()

pdf("Mormoneynw4.pdf", width = 20, height = 10)
ggnet2(Mormoneynw, mode = c("m","n"), label = "org.name", color = "sector", palette = c("Public sector" = "#2c7bb6", 
                                                                                        "Private sector" = "#d7191c", 
                                                                                        "Voluntary sector" = "#fdae61"), 
       label.size = 8, edge.color = "#000000",
       shape = "level", shape.palette = c("startMor" = 19, "startMah" = 19, "startBea" = 19, "startFiz" = 19, 
                                          "village" = 19, 
                                          "district" = 15, 
                                          "regional" = 8, 
                                          "national" = 17, 
                                          "international" = 18),
       size = 10, legend.size = 16, legend.position = "right")
dev.off()

# Mahalevona

pdf("Mahgoodsnw4.pdf", width = 20, height = 10)
ggnet2(Mahgoodsnw, mode = c("m","n"), label = "org.name", color = "sector", palette = c("Public sector" = "#2c7bb6", 
                                                                                        "Private sector" = "#d7191c", 
                                                                                        "Voluntary sector" = "#fdae61"), 
       label.size = 8, edge.color = "#000000",
       shape = "level", shape.palette = c("startMor" = 19, "startMah" = 19, "startBea" = 19, "startFiz" = 19, 
                                          "village" = 19, 
                                          "district" = 15, 
                                          "regional" = 8, 
                                          "national" = 17, 
                                          "international" = 18),
       size = 10, legend.size = 16, legend.position = "right")
dev.off()

pdf("Mahmoneynw4.pdf", width = 20, height = 10)
ggnet2(Mahmoneynw, mode = c("m","n"), label = "org.name", color = "sector", palette = c("Public sector" = "#2c7bb6", 
                                                                                        "Private sector" = "#d7191c", 
                                                                                        "Voluntary sector" = "#fdae61"), 
       label.size = 8, edge.color = "#000000",
       shape = "level", shape.palette = c("startMor" = 19, "startMah" = 19, "startBea" = 19, "startFiz" = 19, 
                                          "village" = 19, 
                                          "district" = 15, 
                                          "regional" = 8, 
                                          "national" = 17, 
                                          "international" = 18),
       size = 10, legend.size = 16, legend.position = "right")
dev.off()


###################### Plotting the institutions/village network graphs with labels ######################################

# Morafeno

pdf("Morinstnw4.pdf", width = 30, height = 12)
ggnet2(MorInstnw, mode = c("w","z"), label = "org.name", color = "sector", palette = c("Public sector" = "#99d8c9", 
                                                                                       "Private sector" = "#810f7c", 
                                                                                       "Voluntary sector" = "#3182bd"), 
       label.size = 4, shape = "level", shape.palette = c("startMor" = 17, "startMah" = 19, "startBea" = 19, "startFiz" = 19, "village" = 19, "district" = 19, "regional" = 19, 
                                                          "national" = 19, "international" = 19),
       size = 25, legend.size = 16, legend.position = 0)
dev.off()

# Mahalevona

pdf("Mahinstnw4.pdf", width = 30, height = 12)
ggnet2(MahInstnw, mode = c("w","z"), label = "org.name", color = "sector", palette = c("Public sector" = "#99d8c9", 
                                                                                       "Private sector" = "#810f7c", 
                                                                                       "Voluntary sector" = "#3182bd"), 
       label.size = 4, shape = "level", shape.palette = c("startMor" = 19, "startMah" = 17, "startBea" = 19, "startFiz" = 19, "village" = 19, "district" = 19, "regional" = 19, 
                                                          "national" = 19, "international" = 19),
       size = 25, legend.size = 16, legend.position = 0)
dev.off()

###################### Plotting the institutions/village network graphs with labels  ######################################

# Morafeno

pdf("Morinstnw3.pdf", width = 30, height = 12)
ggnet2(MorInstnw, mode = c("w","z"), label = FALSE, color = "sector", palette = c("Public sector" = "#99d8c9", 
                                                                                  "Private sector" = "#810f7c", 
                                                                                  "Voluntary sector" = "#3182bd"), 
       label.size = 4, shape = "level", shape.palette = c("startMor" = 17, "startMah" = 19, "startBea" = 19, "startFiz" = 19, "village" = 19, "district" = 19, "regional" = 19, 
                                                          "national" = 19, "international" = 19),
       size = 25, legend.position = "none")
dev.off()

# Mahalevona

pdf("Mahinstnw3.pdf", width = 30, height = 12)
ggnet2(MahInstnw, mode = c("w","z"), label = FALSE, color = "sector", palette = c("Public sector" = "#99d8c9", 
                                                                                  "Private sector" = "#810f7c", 
                                                                                  "Voluntary sector" = "#3182bd"), 
       label.size = 4, shape = "level", shape.palette = c("startMor" = 19, "startMah" = 17, "startBea" = 19, "startFiz" = 19, "village" = 19, "district" = 19, "regional" = 19, 
                                                          "national" = 19, "international" = 19),
       size = 25, legend.position = "none")
dev.off()


###################### Plotting the village network graphs (flows and institutions) grid without labels ######################################
# Flows - Morafeno

ggMor <- ggnet2(Morgoodsnw, mode = c("x","y"), label = FALSE, color = "sector", palette = c("Public sector" = "#2c7bb6", 
                                                                                            "Private sector" = "#d7191c", 
                                                                                            "Voluntary sector" = "#fdae61"), 
       label.size = 4, edge.color = "#000000", 
       shape = "level", shape.palette = c("startMor" = 19, "startMah" = 19, "startBea" = 19, "startFiz" = 19, "village" = 19, "district" = 19, "regional" = 19, 
                                          "national" = 19, "international" = 19),
       size = 3, legend.size = 16, legend.position = "none")

gmMor <- ggnet2(Mormoneynw, mode = c("x","y"), label = FALSE, color = "sector", palette = c("Public sector" = "#2c7bb6", 
                                                                                            "Private sector" = "#d7191c", 
                                                                                            "Voluntary sector" = "#fdae61"), 
       label.size = 4, edge.color = "#000000",
       shape = "level", shape.palette = c("startMor" = 19, "startMah" = 19, "startBea" = 19, "startFiz" = 19, "village" = 19, "district" = 19, "regional" = 19, 
                                          "national" = 19, "international" = 19),
       size = 3, legend.size = 16, legend.position = "none")

# Flows - Mahalevona

ggMah <- ggnet2(Mahgoodsnw, mode = c("x","y"), label = FALSE, color = "sector", palette = c("Public sector" = "#2c7bb6", 
                                                                                            "Private sector" = "#d7191c", 
                                                                                            "Voluntary sector" = "#fdae61"), 
                label.size = 4, edge.color = "#000000",
                shape = "level", shape.palette = c("startMor" = 19, "startMah" = 19, "startBea" = 19, "startFiz" = 19, "village" = 19, "district" = 19, "regional" = 19, 
                                                   "national" = 19, "international" = 19),
                size = 3, legend.size = 16, legend.position = "none")

gmMah <- ggnet2(Mahmoneynw, mode = c("x","y"), label = FALSE, color = "sector", palette = c("Public sector" = "#2c7bb6", 
                                                                                            "Private sector" = "#d7191c", 
                                                                                            "Voluntary sector" = "#fdae61"), 
                label.size = 4, edge.color = "#000000",
                shape = "level", shape.palette = c("startMor" = 19, "startMah" = 19, "startBea" = 19, "startFiz" = 19, "village" = 19, "district" = 19, "regional" = 19, 
                                                   "national" = 19, "international" = 19),
                size = 3, legend.size = 16, legend.position = "none")

# Institutions - Morafeno

ginstMor <- ggnet2(MorInstnw, mode = c("w","z"), label = FALSE, color = "sector", palette = c("Public sector" = "#2c7bb6", 
                                                                                              "Private sector" = "#d7191c", 
                                                                                              "Voluntary sector" = "#fdae61"), 
       label.size = 4, shape = "level", shape.palette = c("startMor" = 19, "startMah" = 19, "startBea" = 19, "startFiz" = 19, "village" = 19, "district" = 19, "regional" = 19, 
                                                          "national" = 19, "international" = 19),
       size = 3, edge.color = "#000000", legend.position = "none")

# Institutions - Mahalevona

ginstMah <- ggnet2(MahInstnw, mode = c("w","z"), label = FALSE, color = "sector", palette = c("Public sector" = "#2c7bb6", 
                                                                                              "Private sector" = "#d7191c", 
                                                                                              "Voluntary sector" = "#fdae61"), 
       label.size = 4, shape = "level", shape.palette = c("startMor" = 19, "startMah" = 19, "startBea" = 19, "startFiz" = 19, "village" = 19, "district" = 19, "regional" = 19, 
                                                          "national" = 19, "international" = 19),
       size = 3, edge.color = "#000000", legend.position = "none")

#==================================================================================
######## title
title1 = ggtitle("Actors in the entire network")
titlegMor = ggtitle("Goods")
titlegMah = ggtitle("")
titlem = ggtitle("Money")
titlei = ggtitle("Information")
titleinst = ggtitle("Institutions")
title0 = ggtitle(" ")

######## legend
install.packages("gridExtra")
library("gridExtra")
install.packages("png")
library(png)
install.packages("gtable")
library(gtable)
install.packages("grid")
library(grid)

legend.png <- readPNG("legend.png")
legend <- rasterGrob(legend.png)

######## Plot multiple graphs  

pdf("Overview_graph.pdf", width = 7, height = 10)
g2 <- grid.arrange (arrangeGrob (ggMor + titlegMor, ggMah + titlegMah, ncol = 2),
                    arrangeGrob (gmMor + titlem, gmMah + title0, ncol = 2),
                    arrangeGrob (ginstMor + titleinst, ginstMah + title0, ncol = 2), 
                    arrangeGrob (legend, ncol = 1),top = "", nrow=4) 

dev.off()
####################################### THE END :) ##########################################################################